********************************************************************************
* MASTER do-file                                                               *
* Data cleaning and construction of an information-by-age dataset              * 
* Starting Cohort 6 of the National Educational Panel Study                    *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

*** Globals ********************************************************************

* folders with data source (data) and dofiles (dofile)  and to store new data files (savedta) and log files (savelog)
global data   	[specify path to folder where you stored the original NEPS datasets]
global dofile	[specify path to folder where you stored the do-files]
global savedta	[specify path to folder where you want to save new datasets created by the syntax]
global savelog	[specify path to folder where you want to save log files]

* version of NEPS-SC6 data
global SUF		"14-0-0"  // specify data version (this syntax has been created based on version 14-0-0)	  

*** Download ado files *********************************************************

* NEPS tools
net install nepstools, from(http://nocrypt.neps-data.de/stata) replace

*** Store relevant NEPS datasets with NEPSmiss *********************************
clear 
do "${dofile}\nepsmiss.do"

*** Recode and store basic information in wide format **************************

* Participation in waves
clear 
do "${dofile}\wavepart.do"

* Recode of time-invariant information (for imputation]
clear
do "${dofile}\basicinfo.do"

*** Expand spell data to monthly infromation ***********************************
clear
do "${dofile}\month_episodes.do"

*** Recode of information on education  ****************************************

* School-leaving degrees: basic recodes
clear
do "${dofile}\school_basics.do"

* School-leaving degrees: plausibility checks and data cleaning
clear
do "${dofile}\school_plausi.do"

* School-leaving degrees: recodes of key variables
clear
do "${dofile}\school_recode.do"

* Vocational degrees: basic recodes
clear
do "${dofile}\voctrain_basics.do"

* Vocational degrees: plausibility checks and data cleaning
clear
do "${dofile}\voctrain_plausi.do"

* Vocational degrees: recodes of key variables
clear
do "${dofile}\voctrain_recode.do"

* Merge information on school-leaving and vocational degrees
clear
do "${dofile}\educ_merge.do"

* Transfer education data into information-by-age format (wide format)
clear
do "${dofile}\educ_age.do"

*** Recode of labor market information *****************************************

* Income: plausibility checks and data cleaning
clear
do "${dofile}\income_plausi.do"

* Income: recodes and transfer into information-by-age format (wide format) 
clear
do "${dofile}\income_age.do"

* Occupation: recodes and transfer into information-by-age format (wide format)
clear
do "${dofile}\occupation_age.do"

* Identify date of first significant employment 
clear
do "${dofile}\date_employ1.do"

*** Merge data *****************************************************************

* Merge data into complaete information-by-age dataset
clear
do "${dofile}\merge_age.do"

exit


































