********************************************************************************
* Recode school basics                                              		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\month_episodes", clear
keep if sptype==22 // keep only school spells

*** merge information on year of birth and immigration history 
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(1 3) keepusing(birthdate migration_age)
* generate age in months and in years
gen agem=month-birthdate
lab var agem "age in months"
gen agey=(month-birthdate)/12
lab var agey "age in years"

*** merge information from school dataset 
gen subspell = 0   
merge m:1 ID_t splink subspell using "${savedta}\SC6_spSchool_D_${SUF}.dta", ///
nogen keep(1 3) keepusing(ts11204_ha ts11209 ts1112c_g1 ts11213 ts11218 ts11103_g1 ts11202_g2 t724801 t724802 t724803 t724804 t724805)
sort ID_t month monthnr

* type of school (ts11204_ha) 
fre ts11204_ha
rename ts11204_ha schooltype
recode schooltype . .b=.a 
lab var schooltype "type of school"
lab copy en1913ext1 schooltype
lab def schooltype .a "indeterminate", modify
lab val schooltype schooltype
fre schooltype

* ongoing episode (ts1112c_g1) 
rename ts1112c_g1 schoolcont
fre schoolcont

* school leaving degree (ts11209)
rename ts11209 schooldegree
recode schooldegree . .b=.a
replace schooldegree=.w if schooldegree==.a & schoolcont==1
lab var schooldegree "school leaving degree"
lab copy en2978ext1 schooldegree
lab def schooldegree .a"indeterminate" .b" " .c" " .w"still attending this school" .x"no qualification intended" .y"no qualification", modify
lab val schooldegree schooldegree
fre schooldegree

* grade point average of school leaving degree (ts11218) 
rename ts11218 schoolgpa
recode schoolgpa (. .b .c .e .m .y=.a) 
replace schoolgpa=.w if schoolgpa>=. & schoolcont==1
replace schoolgpa=.x if schoolgpa>=. & schooldegree==.x
replace schoolgpa=.y if schoolgpa>=. & schooldegree==.y
lab var schoolgpa "GPA school leaving degree"
lab copy enext3 schoolgpa
lab def schoolgpa 999"" .a"indeterminate" .w"still attending this school" .x"no qualification intended" .y"no qualification", modify
lab val schoolgpa schoolgpa
fre schoolgpa

* school attended in Germany (ts11103_g1)
rename ts11103_g1 gerschool
recode gerschool (. .b=.a) 
replace gerschool=1 if gerschool==.x // count as GER if GER and another country
lab var gerschool "school attended in Germany"
lab copy en177ext2 gerschool
lab def gerschool .a"indeterminate" .b" " .o" " .p" " .x" " .y" ", modify
lab val gerschool gerschool
bys ID_t splink: egen temp=min(agey)
replace gerschool=2 if gerschool==.a & temp<migration_age & migration_age<. // replace if immigration later than school attendance 
drop temp
sort ID_t month
fre gerschool

* recognition of school-leaving qualification from abroad in Germany (ts11213)
recode ts11213 (1 .y=1 "recognized") (2=0 "not recognized") (.b .c=.a "indeterminate"), into(recog)
lab var recog "recognition of foreign school-leaving degree"
drop ts11213

* federal state (ts11202_g2)
rename ts11202_g2 fedschool
replace fedschool=.x if gerschool==2
replace fedschool=20 if gerschool==1 & !inrange(fedschool,1,16)
recode fedschool . .b .c=.a 
lab var fedschool "federal state of school"
lab copy en1619ext1 fedschool
lab def fedschool 20"Germany (not further specified)" .a"indeterminate" .l" " .x"abroad" .y" ", modify
lab val fedschool fedschool
fre fedschool

* field of abitur (t724801-t724805)
local i=1
lab copy en3137ext1 abifield
lab def abifield .a"indeterminate" .b" " .d" " .g"does not apply" .m"missing by design", modify
foreach v of varlist t72480*{ 
   lab val `v' abifield
   lab var `v' "field of Abitur `i'"
   rename `v' abifield`i' 
   recode abifield`i' (. .b .c .d=.a)
   local i=`i'+1
}
fre abifield*

*** save dataset
order schooltype schoolcont schooldegree recog schoolgpa abifield* gerschool fedschool, after(subspell)
sort ID_t month monthnr
save "${savedta}\school_basics", replace
exit 



