********************************************************************************
* Recode of school variables                                         		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\school_plausi.dta"

*** GENERATE CUMULATIVE VARIABLE INDICATING HIGHEST SCHOOL DEGREE **************

*** generate variable indicating that any new school-leaving degree has been obtained
gen schooldegree_add=1 if month==end & inlist(schooldegree,1,2,3,4,5,6,7,.a)
lab var schooldegree_add "additional school-leaving degree obtained" 

*** recode school degree variable 
* create hierarchical order of degrees
lab def schooldegree2 ///
0 "no degree" ///
1 "no degree or more (abroad)" ///
2 "no degree or more (GER)" ///
3 "special needs (abroad+recog)" ///
4 "special needs (GER)" ///
5 "special needs or more (abroad)" ///
6 "special needs or more (GER)" ///
7 "Haupt (abroad+recog)" ///
8 "Haupt (GER)" ///
9 "Haupt or more (abroad)" ///
10 "Haupt or more (GER)" ///
11 "qual.Haupt (abroad+recog)" ///
12 "qual.Haupt (GER)" ///
13 "qual.Haupt or more (abroad)" ///
14 "qual.Haupt or more (GER)" ///
15 "Mittl.Reife (abroad+recog)" ///
16 "Mittl.Reife (GER)" ///
17 "Mittl.Reife or more (abroad)" ///
18 "Mittl.Reife or more (GER)" ///
19 "FH-Reife (abroad+recog)" ///
20 "FH-Reife (GER)" ///
21 "FH-Reife or more (abroad)" ///
22 "FH-Reife or more (GER)" ///
23 "Abitur (abroad+recog)" ///
24 "Abitur (GER)" ///
.a"indeterminate (abroad+recog)" /// 
.b"indeterminate (GER)" /// 
.c"rec.ind./abroad:Haupt" ///
.d"rec.ind./abroad:qual.Haupt" ///
.e"rec.ind./abroad:MR" ///
.f"rec.ind./abroad:FHR" ///
.g"rec.ind./abroad:Abitur" ///
.h"rec.ind./abroad:indeterm."
* first step: recode schooldegree variable into new categories (first recode all cases into full degree categories/GER) 
recode schooldegree (.w .x .y=0) (6=4) (1=8) (2=12) (3=16) (4=20) (5=24) (.a 7=.b), into(schooldegree2)
lab val schooldegree2 schooldegree2
lab var schooldegree2 "school leaving degree (hierarchical)"
ta schooldegree schooldegree2,m
* second step: sort degrees into different categories that have been obtained abroad and have been recognized in GER
// no recodes for gerschool==.a & recog==. (252 cases), assuming that degrees have been obtained in GER (all are non-migrants)
replace schooldegree2=schooldegree2-1 if inrange(schooldegree2,4,24) & gerschool==2 & recog==1
replace schooldegree2=.a if schooldegree2==.b & gerschool==2 & recog==1
tab schooldegree2 gerschool,m
tab schooldegree2 recog,m
* third step: recode degrees that have been obtained abroad but have not been recognized in GER as "no degree"
replace schooldegree2=0 if recog==0 
tab schooldegree2 gerschool,m
tab schooldegree2 recog,m
* fourth step: sort cases with degrees obtained abroad and indeterminate information about recognition status into separate categories 
replace schooldegree2=.c if schooldegree2==8 & gerschool==2 & recog>=.
replace schooldegree2=.d if schooldegree2==12 & gerschool==2 & recog>=.
replace schooldegree2=.e if schooldegree2==16 & gerschool==2 & recog>=.
replace schooldegree2=.f if schooldegree2==20 & gerschool==2 & recog>=.
replace schooldegree2=.g if schooldegree2==24 & gerschool==2 & recog>=.
replace schooldegree2=.h if schooldegree2==.b & gerschool==2 & recog>=. 
tab schooldegree2 gerschool,m
tab schooldegree2 recog,m

*** generate cumulative variable indicating highest school leaving degree per month
* generate variable indicating schooldegree at end of spell
bys ID_t splink: egen temp1=max(month)
gen temp2=schooldegree2 if temp1==month
* generate variable indicating highest school leaving degree by month
sort ID_t month
gen schooldegree_cum=0
replace schooldegree_cum=temp2 if temp2!=.
replace schooldegree_cum=schooldegree_cum[_n-1] if schooldegree_cum[_n-1]<. & (schooldegree_cum[_n-1]>schooldegree_cum| schooldegree_cum>=.) & ID_t==ID_t[_n-1]
lab val schooldegree_cum schooldegree2
lab var schooldegree_cum "highest school leaving degree by month (cumulative)"
//list ID_t splink month temp1 schooldegree2 temp2 schooldegree_cum, sepby(ID_t) 
* correct for spells with indeterminate information about school leaving degrees
replace temp2=1 if inlist(schooldegree2,.a,.c,.d,.e,.f,.g,.h) & schooldegree_cum==0 & temp1==month // no degree or more/abroad
replace temp2=5 if inlist(schooldegree2,.a,.c,.d,.e,.f,.g,.h) & inlist(schooldegree_cum,3,4) & temp1==month // special needs or more/abroad
replace temp2=9 if inlist(schooldegree2,.a,.d,.e,.f,.g,.h) & inlist(schooldegree_cum,7,8) & temp1==month // Haupt or more/abroad
replace temp2=13 if inlist(schooldegree2,.a,.e,.f,.g,.h) & inlist(schooldegree_cum,11,12) & temp1==month // qual.Haupt or more/abroad
replace temp2=17 if inlist(schooldegree2,.a,.f,.g,.h) & inlist(schooldegree_cum,15,16) & temp1==month // MR or more/abroad
replace temp2=21 if inlist(schooldegree2,.a,.g,.h) & inlist(schooldegree_cum,19,20) & temp1==month // FHR or more/abroad
replace temp2=2 if schooldegree2==.b & schooldegree_cum==0 & temp1==month // no degree or more/GER
replace temp2=6 if schooldegree2==.b & inlist(schooldegree_cum,3,4) & temp1==month // special needs or more/GER
replace temp2=10 if schooldegree2==.b & inlist(schooldegree_cum,7,8) & temp1==month // Haupt or more/GER
replace temp2=14 if schooldegree2==.b & inlist(schooldegree_cum,11,12) & temp1==month // qual.Haupt or more/GER
replace temp2=18 if schooldegree2==.b & inlist(schooldegree_cum,15,16) & temp1==month // MR or more/GER
replace temp2=22 if schooldegree2==.b & inlist(schooldegree_cum,19,20) & temp1==month // FHR or more/GER
replace schooldegree_cum=0 // update variable 
replace schooldegree_cum=temp2 if temp2!=.
replace schooldegree_cum=schooldegree_cum[_n-1] if schooldegree_cum[_n-1]<. & (schooldegree_cum[_n-1]>schooldegree_cum| schooldegree_cum>=.) & ID_t==ID_t[_n-1]
ta schooldegree_cum,m // 1 observation with schooldegree_cum==.d --> inspect
gen temp3a=1 if schooldegree_cum>.
bys ID_t: egen temp3b=max(temp3a) 
sort ID_t month
list month agey fedschool schooltype schooldegree schooldegree2 schooldegree_cum recog dur if temp3b==1
replace schooldegree_cum=0 if schooldegree_cum>. & temp3a==1 & schooldegree_cum[_n+1]==0 & dur==1 & agey<14
ta schooldegree_cum,m 
//list ID_t splink month temp1 schooldegree2 temp2 schooldegree_cum, sepby(ID_t)


*** Save data (large file)******************************************************
gen schooldta=1 // indicator for dataset
preserve
drop temp1 temp3a temp3b
compress
save "${savedta}\school_recode.dta", replace	
restore


*** Save data (compressed file) ************************************************
* collapse data and store lines with infos when school leaving degree changes
keep if inrange(temp2,1,12)
drop temp*
compress
* save data
save "${savedta}\school_recode_comp.dta", replace	
exit



