********************************************************************************
* Recode of vocational training variables                           		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\voctrain_plausi.dta"

*** GENERATE CUMULATIVE VARIABLE INDICATING HIGHEST VOCATIONAL DEGREE **********

*** generate variable indicating that any new school-leaving degree has been obtained
gen vocdegree_add=1 if month==end & inlist(vocdegree,1,2,3,4,5,.a)
lab var vocdegree_add "additional vocational degree obtained" 

*** recode vocational degree variable 
* create hierarchical order of degrees
lab def vocdegree2 ///
0 "no voc.degree" ///
1 "no voc.degree or more (abroad)" ///
2 "no voc.degree or more (GER)" ///
3 "VOC1 (abroad)" ///
4 "VOC1 (GER)" ///
5 "VOC1 or more (abroad)" ///
6 "VOC1 or more (GER)" ///
7 "VOC2 (abroad)" ///
8 "VOC2 (GER)" ///
9 "VOC2 or more (abroad)" ///
10 "VOC2 or more (GER)" ///
11 "HE1 (abroad)" ///
12 "HE1 (GER)" ///
13 "HE1 or more (abroad)" ///
14 "HE1 or more (GER)" ///
15 "HE2 (abroad)" ///
16 "HE2 (GER)" ///
.a "indeterminate (GER)" ///
.b "indeterminate (abroad)"
recode vocdegree (.w .y=0) (5 .a=.a) (1=4) (2=8) (3=12) (4=16), into(vocdegree2)
lab val vocdegree2 vocdegree2
tab vocdegree vocdegree2,m
replace vocdegree2=vocdegree2-1 if inrange(vocdegree2,4,16) & gertrain==2 
replace vocdegree2=.b if vocdegree2==.a & gertrain==2
tab vocdegree2 gertrain,m // gertrain==.a are assumed to be degrees obtained in GER (migration_age==.b for all cases) 

*** generate cumulative variable indicating highest vocational degree 
* generate variable indicating vocational degree at end of spell
bys ID_t splink: egen temp1=max(month)
gen temp2=vocdegree2 if temp1==month
* generate variable indicating highest vocational degree by month
sort ID_t month vocdegree2
gen vocdegree_cum=0
replace vocdegree_cum=temp2 if temp2!=.
replace vocdegree_cum=vocdegree_cum[_n-1] if vocdegree_cum[_n-1]<. & (vocdegree_cum[_n-1]>vocdegree_cum | vocdegree_cum>=.) & ID_t==ID_t[_n-1]
lab val vocdegree_cum vocdegree2
lab var vocdegree_cum "highest vocational degree by month (cumulative)"
//list ID_t splink month monthnr_voc temp1 vocdegree2 temp2 vocdegree_cum, sepby(ID_t) 
* correct for spells with indeterminate information about vocational degrees
replace temp2=0 if vocdegree2==.b & inlist(voctype,12,13) & temp1==month
replace temp2=0 if vocdegree2==.a & inlist(voctype,12,13) & temp1==month
replace temp2=1 if vocdegree2==.b & inlist(vocdegree_cum,0,.a,.b) & inlist(voctype,1,2,3,4,5,6,7,8,9,10,11,14,15,16,.a) & temp1==month
replace temp2=2 if vocdegree2==.a & inlist(vocdegree_cum,0,.a,.b) & inlist(voctype,1,2,3,4,5,6,7,8,9,10,11,14,15,16,.a) & temp1==month
replace temp2=5 if vocdegree2==.b & vocdegree_cum==3 & inlist(voctype,3,4,5,6,7,8,9,10,11,14,15,16,.a) & temp1==month
replace temp2=6 if vocdegree2==.a & vocdegree_cum==4 & inlist(voctype,3,4,5,6,7,8,9,10,11,14,15,16,.a) & temp1==month
replace temp2=9 if vocdegree2==.b & vocdegree_cum==7 & inlist(voctype,5,6,7,8,9,10,14,15,.a) & temp1==month
replace temp2=10 if vocdegree2==.a & vocdegree_cum==8 & inlist(voctype,5,6,7,8,9,10,14,15,.a) & temp1==month
replace temp2=13 if vocdegree2==.b & vocdegree_cum==11 & inlist(voctype,9,14,15,.a) & temp1==month
replace temp2=14 if vocdegree2==.a & vocdegree_cum==12 & inlist(voctype,9,14,15,.a) & temp1==month
replace vocdegree_cum=0 // update variable 
replace vocdegree_cum=temp2 if temp2!=.
replace vocdegree_cum=vocdegree_cum[_n-1] if vocdegree_cum[_n-1]<. & (vocdegree_cum[_n-1]>vocdegree_cum| vocdegree_cum>=.) & ID_t==ID_t[_n-1]
//list ID_t splink month monthnr_voc temp1 voctype vocdegree2 temp2 vocdegree_cum, sepby(ID_t)


*** Save data (large file)******************************************************
bys ID_t month: egen temp3a=max(vocdegree2) // keep highest vocational degree per month
bys ID_t month: egen temp3b=max(vocdegree2) if temp3a==., missing  // take into account missing values
keep if vocdegree2==temp3a | (temp3a==. & vocdegree2==temp3b)
bys ID_t month: gen temp4=_n
keep if temp4==1 
gen voctraindta=1 // indicator for dataset
preserve
drop temp1 temp3a temp3b temp4 monthnr_voc monthnr
compress
save "${savedta}\voctrain_recode.dta", replace	
restore


*** Save data (compressed file) ************************************************
* collapse data and store lines with infos when vocational degree changes
keep if inrange(temp2,1,16)
* save data 
drop temp* monthnr_voc monthnr
compress
save "${savedta}\voctrain_recode_comp.dta", replace	
exit



